]> de.git.xonotic.org Git - xonotic/darkplaces.git/commitdiff
Change darkplaces email address to darkplacesengine (on gmail) since
authorhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Mon, 2 Jan 2017 00:14:36 +0000 (00:14 +0000)
committerhavoc <havoc@d7cf8633-e32d-0410-b094-e92efae38249>
Mon, 2 Jan 2017 00:14:36 +0000 (00:14 +0000)
gmail has better spam filtering than the old host

git-svn-id: svn://svn.icculus.org/twilight/trunk/darkplaces@12314 d7cf8633-e32d-0410-b094-e92efae38249

bih.c
bih.h
darkplaces.txt
menu.c

diff --git a/bih.c b/bih.c
index 7a25c6680a02d58381999c3c4628e296286db789..749cae2d3fcc56635bcb33d41e2dd3f2f201fb3b 100644 (file)
--- a/bih.c
+++ b/bih.c
@@ -1,5 +1,5 @@
 
-// This code written in 2010 by Forest Hale (lordhavoc ghdigital com), and placed into public domain.
+// This code written in 2010 by Forest Hale (darkplacesengine gmail com), and placed into public domain.
 
 #include <stdlib.h>
 #include <string.h>
diff --git a/menu.c b/menu.c
index 6295d4620c5b1120aa3dd6b542097dcdb13aad43..f7abc2d19515aa55cea4c035303c8fde70ff40dc 100644 (file)
--- a/menu.c
+++ b/menu.c
@@ -4138,7 +4138,7 @@ void M_GameOptions_Draw (void)
                        M_Print(x, 146, " More than 255 players??");
                        M_Print(x, 154, "  First, question your  ");
                        M_Print(x, 162, "   sanity, then email   ");
-                       M_Print(x, 170, " lordhavoc@ghdigital.com");
+                       M_Print(x, 170, "darkplacesengine@gmail.com");
                }
                else
                        m_serverInfoMessage = false;
diff --git a/bih.h b/bih.h
index 43b659e97f6753aa5fd8e9fb7756aca0035741bc..4be1564fda8bcb7f5f34c368e7872439bd0dc335 100644 (file)
--- a/bih.h
+++ b/bih.h
@@ -1,5 +1,5 @@
 
// This code written in 2010 by Forest Hale (lordhavoc ghdigital com), and placed into public domain.
 
 // Based on information in http://zach.in.tu-clausthal.de/papers/vrst02.html (in particular vrst02_boxtree.pdf)
 
index 4e0507385c5d5287064a5e09ea90b3cbf98f61d4..569879c35d30a655dab05bc234c4f2a1499a8e3f 100644 (file)
@@ -7,7 +7,7 @@ DarkPlaces engine is the result, I hope everyone likes it.
 
 I am not very good at writing documentation, so this readme is organized as a feature list, with information on each feature, I hope it is still adequate documentation.
 
-If you have any suggestions for features to document in detail in the readme or any other questions/comments/bugreports/suggestions/etc, send me an email with the address lordhavoc ghdigital com (add @ and . characters as appropriate)
+If you have any suggestions for features to document in detail in the readme or any other questions/comments/bugreports/suggestions/etc, send me an email with the address darkplacesengine gmail com (add @ and . characters as appropriate)
 
 
 
@@ -1,5 +1,5 @@
 
-// This code written in 2010 by Forest Hale (lordhavoc ghdigital com), and placed into public domain.
+// This code written in 2010 by Forest Hale (darkplacesengine gmail com), and placed into public domain.
 
 // Based on information in http://zach.in.tu-clausthal.de/papers/vrst02.html (in particular vrst02_boxtree.pdf)